function iqstream = img2iqstream(inputFileName, Fs, lineTime)
% Read input image
inputImage = imread(inputFileName);

% Set FFT size to be double the image size so that the edge of the spectrum
% stays clear preventing some bandfilter artifacts

NFFT = 2*size(inputImage,2);

repetitions = ceil(lineTime*Fs / NFFT);
% Repeat image lines until each one comes often enough to reach the desired
% line time
ffts = repmat(inputImage(:,:,1), repetitions, 1);
ffts = (ffts./16).^2;
ffts = flipud(ffts)./256;

% Embed image in center bins of the FFT
fftall = zeros(size(ffts,1), NFFT);
startbin = NFFT/4;
fftall(:,startbin:startbin+size(inputImage,2)-1) = ffts;

% Generate random phase vectors for the FFT bins, this is important to
% prevent high peaks in the output The phases won't be visible in the
% spectrum end
phases = 2*pi*rand(size(fftall));
rffts = fftall.* exp(1i*phases);
% Perform the FFT per image line, then concatenate them to form the final
% signal
timedata = ifft(ifftshift(rffts,2), NFFT,2);
iqstream = reshape(timedata.',1,[]);
iqstream = iqstream ./max(abs(iqstream));